==> openturns_0.13.1.orig.tar.gz: openturns-0.13.1/lib/src/Uncertainty/Algorithm/Experiments/FixedExperiment.cxx <==
//                                               -*- C++ -*-
/**
 *  @file  FixedExperiment.cxx
 *  @brief Abstract top-level view of an fixedExperiment plane
 *
 *  (C) Copyright 2005-2007 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2008-06-26 13:50:17 +0200 (jeu, 26 jun 2008) $
 *  Id:      $Id: FixedExperiment.cxx 862 2008-06-26 11:50:17Z dutka $
 */
#include "FixedExperiment.hxx"

namespace OpenTURNS {

  namespace Uncertainty {

    namespace Algorithm {

      CLASSNAMEINIT(FixedExperiment);

      /* Default constructor */
      FixedExperiment::FixedExperiment(const String & name):
	WeightedExperiment(name),
	sample_(0, 0)
      {
	// Nothing to do
      }

      /* Constructor with parameters */
      FixedExperiment::FixedExperiment(const NumericalSample sample,
				       const String & name):
	WeightedExperiment(sample.getSize(), name),
	sample_(sample)
      {
	// Nothing to do
      }

      /* Virtual constructor */
      FixedExperiment * FixedExperiment::clone() const
      {
	return new FixedExperiment(*this);
      }

      /* String converter */
      String FixedExperiment::__repr__() const
      {
	OSS oss;
	oss << "class=" << GetClassName()
	    << " name=" << getName()
	    << " distribution=" << distribution_
	    << " size=" << size_;
	return oss;
      }

      /* Sample generation */
      FixedExperiment::NumericalSample FixedExperiment::generate()
      {
	return sample_;
      }

    } /* namespace Algorithm */
  } /* namespace Uncertainty */
} /* namespace OpenTURNS */

==> openturns_0.13.2.orig.tar.gz: openturns-0.13.2/lib/src/Uncertainty/Algorithm/Experiments/FixedExperiment.cxx <==
//                                               -*- C++ -*-
/**
 *  @file  FixedExperiment.cxx
 *  @brief Abstract top-level view of an fixedExperiment plane
 *
 *  (C) Copyright 2005-2010 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2008-06-26 13:50:17 +0200 (jeu, 26 jun 2008) $
 *  Id:      $Id: FixedExperiment.cxx 862 2008-06-26 11:50:17Z dutka $
 */
#include "FixedExperiment.hxx"
#include "UserDefined.hxx"

namespace OpenTURNS {

  namespace Uncertainty {

    namespace Algorithm {

      CLASSNAMEINIT(FixedExperiment);

      typedef Distribution::UserDefined UserDefined;

      /* Default constructor */
      FixedExperiment::FixedExperiment(const String & name):
	WeightedExperiment(name),
	sample_(0, 0)
      {
	// Nothing to do
      }

      /* Constructor with parameters */
      FixedExperiment::FixedExperiment(const NumericalSample & sample,
				       const String & name):
	WeightedExperiment(UserDefined(sample), sample.getSize(), name),
	sample_(sample)
      {
	// Nothing to do
      }

      /* Constructor with parameters */
      FixedExperiment::FixedExperiment(const NumericalSample & sample,
				       const NumericalPoint & weights,
				       const String & name):
	WeightedExperiment(UserDefined(sample, weights), sample.getSize(), name),
	sample_(sample)
      {
	// Add the weights to the upper level class
	weights_ = weights;
      }

      /* Virtual constructor */
      FixedExperiment * FixedExperiment::clone() const
      {
	return new FixedExperiment(*this);
      }

      /* String converter */
      String FixedExperiment::__repr__() const
      {
	OSS oss;
	oss << "class=" << GetClassName()
	    << " name=" << getName()
	    << " distribution=" << distribution_
	    << " size=" << size_;
	return oss;
      }

      /* Sample generation */
      FixedExperiment::NumericalSample FixedExperiment::generate()
      {
	return sample_;
      }

      /* Sample generation with weights */
      FixedExperiment::NumericalSample FixedExperiment::generate(NumericalPoint & weights)
      {
	weights = weights_;
	return sample_;
      }

    } /* namespace Algorithm */
  } /* namespace Uncertainty */
} /* namespace OpenTURNS */
